@@ -3,9 +3,12 @@ from itertools import chain
 from typing import Any, Dict, Generator, List, Optional, Tuple, Union
 
 import mlflow
+from deprecation import deprecated
 from kedro.io import AbstractDataSet, DataSetError
 from mlflow.tracking import MlflowClient
 
+from kedro_mlflow import __version__
+
 MetricItem = Union[Dict[str, float], List[Dict[str, float]]]
 MetricTuple = Tuple[str, float, int]
 MetricsDict = Dict[str, MetricItem]
@@ -14,6 +17,12 @@ MetricsDict = Dict[str, MetricItem]
 class MlflowMetricsDataSet(AbstractDataSet):
     """This class represent MLflow metrics dataset."""
 
+    @deprecated(
+        deprecated_in="0.7.3",
+        removed_in="0.8.0",
+        current_version=__version__,
+        details="Deprecated in favor of 'MlflowMetricDataSet' (for a single metric) or 'MlflowMetricHistoryDataSet '(for the metric evolution over time)",
+    )
     def __init__(
         self,
         run_id: str = None,
@@ -27,6 +36,7 @@ class MlflowMetricsDataSet(AbstractDataSet):
         """
         self._prefix = prefix
         self.run_id = run_id
+        self._logging_activated = True  # by default, logging is activated!
 
     @property
     def run_id(self):
@@ -50,6 +60,19 @@ class MlflowMetricsDataSet(AbstractDataSet):
     def run_id(self, run_id):
         self._run_id = run_id
 
+    # we want to be able to turn logging off for an entire pipeline run
+    # To avoid that a single call to a dataset in the catalog creates a new run automatically
+    # we want to be able to turn everything off
+    @property
+    def _logging_activated(self):
+        return self.__logging_activated
+
+    @_logging_activated.setter
+    def _logging_activated(self, flag):
+        if not isinstance(flag, bool):
+            raise ValueError(f"_logging_activated must be a boolean, got {type(flag)}")
+        self.__logging_activated = flag
+
     def _load(self) -> MetricsDict:
         """Load MlflowMetricDataSet.
 
@@ -93,8 +116,10 @@ class MlflowMetricsDataSet(AbstractDataSet):
         metrics = (
             self._build_args_list_from_metric_item(k, v) for k, v in data.items()
         )
-        for k, v, i in chain.from_iterable(metrics):
-            log_metric(k, v, step=i)
+
+        if self._logging_activated:
+            for k, v, i in chain.from_iterable(metrics):
+                log_metric(k, v, step=i)
 
     def _exists(self) -> bool:
         """Check if MLflow metrics dataset exists.
